﻿using CMS.DataEngine;
using CMS.DocumentEngine;
using CMS.Helpers;
using CMS.Membership;
using CMS.Synchronization;
using CMS.UIControls;
using System;
using System.Linq;

namespace CMSApp.utils
{
    public partial class DestroyVersionHistory : CMSPage
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            var user = MembershipContext.AuthenticatedUser;

            if (!user.IsGlobalAdministrator)
            {
                // This page should only be accessible to global admins
                RequestHelper.Respond404();
                return;
            }
        }

        private void DeleteDocumentHistory(UserInfo user)
        {
            // Get ids of all documents that have version information
            var docQuery = new DataQuery()
                .From("CMS_VersionHistory")
                .Column("DocumentID")
                .Distinct();

            var docIds = docQuery
                .Select(row => int.Parse(row[0].ToString()))
                .ToArray();

            // Use the version manager to destroy document history
            var tree = new TreeProvider(user);
            var versionManager = VersionManager.GetInstance(tree);

            foreach (int docId in docIds)
            {
                versionManager.DestroyDocumentHistory(docId);
            }
        }

        private void DeleteObjectHistory(UserInfo user)
        {
            // Get ids and types of all objects that have version information
            var objectQuery = new DataQuery()
                .From("CMS_ObjectVersionHistory")
                .Columns("VersionObjectType", "VersionObjectID")
                .Distinct();

            var objectVersions = objectQuery
                .Select(row => new
                {
                    ObjectType = row[0].ToString(),
                    ObjectId = int.Parse(row[1].ToString())
                })
                .ToArray();

            // Destroy object history
            foreach (var objectVersion in objectVersions)
            {
                ObjectVersionManager.DestroyObjectHistory(objectVersion.ObjectType, objectVersion.ObjectId);
            }
        }

        protected void DeleteDocumentHistory_Click(object sender, EventArgs e)
        {
            var user = MembershipContext.AuthenticatedUser;
            DeleteDocumentHistory(user);
        }

        protected void DeleteObjectHistory_Click(object sender, EventArgs e)
        {
            var user = MembershipContext.AuthenticatedUser;
            DeleteObjectHistory(user);
        }
    }
}